import { useMemo, useRef } from 'react';
/**
 * 节流刷新
 * @param factory
 * @param deps
 * @param delay
 * @returns
 */
export function useThrottledMemo(factory, deps, delay) {
  var time = delay || 5;
  var valueRef = useRef();
  var timeRef = useRef(0);
  return useMemo(function () {
    var currentTime = Date.now();
    if (valueRef.current === null || currentTime - timeRef.current >= time) {
      valueRef.current = factory();
      timeRef.current = currentTime;
    }
    return valueRef.current;
  }, deps);
}
/**
 * 防抖刷新
 * @param factory
 * @param deps
 * @param delay
 * @returns
 */
export function useDebouncedMemo(factory, deps, delay) {
  var time = delay || 5;
  var timerRef = useRef();
  return useMemo(function () {
    clearTimeout(timerRef.current);
    timerRef.current = setTimeout(function () {
      factory();
    }, time);
    return function () {
      clearTimeout(timerRef.current);
    };
  }, deps);
}